@@ -3,7 +3,7 @@
 use strict;
 use warnings;
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 die "Usage: ver MODULE1 MODULE2 .. MODULEN\n"
     unless @ARGV;
@@ -18,21 +18,27 @@ foreach my $mod ( @ARGV ) {
 
 $max_length+=2;
 
+print "\n";
 foreach my $mod ( @ARGV ) {
-    eval "use $mod; printf qq|        %-${max_length}s => %s,$/|,"
-            . "q|'$mod'|, $mod->VERSION;";
+    my $version;
+    eval "use $mod; \$version = $mod->VERSION;";
     if ( $@ ) {
         print "\nERROR: $@\n";
     }
+
+    $version ||= 0;
+
+    printf qq|        %-${max_length}s => %s,\n|, qq|'$mod'|, $version;
 }
 
 print "\n\n";
 
 print qq|    use_ok('$_');\n| for @ARGV;
+print "\n";
 
 =head1 NAME
 
-list_versions.pl - "easify" writing Makefile.PL and Build.PL by
+list_versions - "easify" writing Makefile.PL and Build.PL by
 easily listing versions of modules.
 
 =head1 DESCRIPTION
@@ -70,6 +76,8 @@ This is a sample of printed output for the USAGE sample:
         use_ok('Some::OtherModule');
         use_ok('LWP');
 
+I<Note:> if Module->VERSION returns C<undef> the version will be indicated
+as C<0>.
 
 =head1 AUTHOR
 
